package com.ruoyi.system.mapper;

import com.ruoyi.system.entity.DragTableStatistic;

import java.util.List;

/**
 * 动态表格统计Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-27
 */
public interface DragTableStatisticMapper 
{
    /**
     * 查询动态表格统计
     * 
     * @param id 动态表格统计主键
     * @return 动态表格统计
     */
    DragTableStatistic selectDragTableStatisticById(Long id);

    /**
     * 查询动态表格统计列表
     * 
     * @param dragTableStatistic 动态表格统计
     * @return 动态表格统计集合
     */
    List<DragTableStatistic> selectDragTableStatisticList(DragTableStatistic dragTableStatistic);

    /**
     * 新增动态表格统计
     * 
     * @param dragTableStatisticList 动态表格统计
     * @return 结果
     */
    int batchInsertDragTableStatistic(List<DragTableStatistic> dragTableStatisticList);

    /**
     * 修改动态表格统计
     * 
     * @param dragTableStatistic 动态表格统计
     * @return 结果
     */
    int updateDragTableStatistic(DragTableStatistic dragTableStatistic);

    /**
     * 删除动态表格统计
     * 
     * @param tableKey 动态表格统计主键
     * @return 结果
     */
    int deleteDragTableStatisticByTableKey(String tableKey);

    /**
     * 批量删除动态表格统计
     *
     * @param tableKeys 动态表格统计主键
     * @return 结果
     */
    int deleteDragTableStatisticByTableKeys(List<String> tableKeys);

    /**
     * 批量删除动态表格统计
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteDragTableStatisticByIds(List<Long> ids);

    /**
     * 根据tableKey查询统计编号
     */
    List<Long> selectIdsByTableKey(String tableKey);

    /**
     * 根据tableKey查询sqlKey
     */
    List<String> selectSqlKeyByTableKey(String tableKey);
}
